@@ -24,15 +24,17 @@ DEFAULT_DIALOG = {
         'manager_contact': 'Менеджер Василий +79008001234',
     },
     'main_script': [
-        # При успехе следующим будет исполнен скрипт '003', иначе '003'.
-        {'name': '001', 'success': '002', 'fail': '004'},
+        # При успехе следующим будет исполнен скрипт '003', иначе '005'.
+        {'name': '001', 'success': '002', 'fail': '005'},
         # При любом завершении будет исполнен скрипт '003'.
         {'name': '002'},
         # При любом завершении будет исполнен скрипт '004'.
         {'name': '003'},
+        # При любом завершении будет исполнен скрипт '005'.
+        {'name': '004'},
         # При любом завершении данные будут переданы указанному плагину.
         # Принимать их или нет - решать плагину.
-        {'name': '004', 'plugin': 'example.py'},
+        {'name': '005', 'plugin': 'example.py'},
     ],
     'scripts': {
         '001': {
@@ -47,6 +49,15 @@ DEFAULT_DIALOG = {
             # учитываться.
             # 'partials_begin': 1,
             'say_start': {
+                # Текст можно задавать двумя вариантами:
+                # 'text': 'Первое предложение. Последнее предложение.'
+                # 'text': 'Первое предложение. |Последнее предложение.'
+                # 'texts': ['Первое предложение.', 'Последнее предложение.']
+                # Когда задан список или текст с разделителем, то эти части
+                # синтезируются отдельно и потом соединяются в отдельный файл
+                # голоса. Таким образом можно и нужно отделять часто
+                # синтезируемый текст от редкосинтезируемого.
+
                 # Вместо текста можно указать файл голоса двумя вариантами:
                 # 'voice': '/full/path/to/voice' - без расширения;
                 # 'file': '/full/path/to/voicefile.wav' - с расширением.
@@ -54,7 +65,7 @@ DEFAULT_DIALOG = {
                     'Здравствуйте, с Вами говорит базовая диалоговая модель. '
                     'Меня разрабатывали очень весёлые люди. Поэтому я могу '
                     'быть весьма неожиданной. В принципе обо мне - всё. '
-                    'Позвольте мне теперь узнать о Вас. Представьтесь, '
+                    'Позвольте мне теперь узнать о Вас. |Представьтесь, '
                     'пожалуйста.'
                 ),
                 'escape_digits': '1234567890',
@@ -62,7 +73,7 @@ DEFAULT_DIALOG = {
             },
             'say_success': {
                 'text': _(
-                    '%(caller_name)s, мне очень приятно было распознать '
+                    '%(caller_name)s| мне очень приятно было распознать '
                     'Ваше имя.'
                 ),
             },
@@ -195,7 +206,17 @@ DEFAULT_DIALOG = {
                 },
             },
         },
+        # Этот блок-скрипт запустит плагин, установит переменную, озвучит её
+        # и установит результат False для последовательности `fail`.
         '004': {
+            'type': 'simple_say',
+            'new_buffer': True,
+            'plugin_before': 'example.py',
+            'say_start': {
+                'text': '%(example_plugin_var)s',
+            }
+        },
+        '005': {
             'type': 'simple_say',
             'new_buffer': True,
             'say_start': {
@@ -247,6 +268,7 @@ def get_plugin(work_dir, name):
         internal = path_join(BASE_DIR, 'plugins')
         filename = path_join(internal, name)
         if not exists(filename):
+            logger.error(_('Плагин с именем %r не найден.'), name)
             filename = path_join(internal, 'example.py')
     return filename
 
@@ -341,6 +363,10 @@ def get_logging_config(work_dir):
                 'handlers': ['dialog'],
                 'level': 'INFO',
             },
+            'astersay.backends.tinkoff': {
+                'handlers': ['dialog'],
+                'level': 'INFO',
+            },
         }
     }
     return get_config(work_dir, default, 'logging')
@@ -403,6 +429,46 @@ def get_vosk_config(work_dir):
     return get_config(work_dir, default, 'vosk')
 
 
+def get_tinkoff_config(work_dir):
+    default = {
+        'auth': {
+            'api_key': '',
+            'private_filename': path_join(work_dir, 'tinkoff_private.pem'),
+            'token_filename': path_join(work_dir, 'tinkoff_token.json'),
+            'service_account_id': '',
+            'sub': ''
+        },
+        'recognizer': {
+            'model': 'general',
+            'audio_encoding': 'LINEAR16',
+            'chunk_size': 1024,
+            'language_code': 'ru-RU',
+            'profanity_filter': False,
+            'sample_rate_hertz': 8000,
+            'enable_automatic_punctuation': False,
+            'enable_interim_results': False,
+            'interim_results_interval': 1.0
+        },
+        'synthesizer': {
+            'sample_rate_hertz': 48000,
+            'speed': 1.0,
+            'storage': path_join(work_dir, 'storage'),
+            'voice': 'alyona',
+            'lang': 'ru-RU',
+            'format': 'lpcm',
+            'convertor': {
+                'command': (
+                    'sox -t raw -r 48k -b 16 -e signed-integer -c 1 "%s" '
+                    '-t wav -r 8k -c 1 "%s"'
+                ),
+                'src_format': 'raw',
+                'src_delete': True,
+            }
+        }
+    }
+    return get_config(work_dir, default, 'tinkoff')
+
+
 class Settings:
     """
     Конструктор для объекта управления настройками запускаемого приложения.
@@ -414,6 +480,7 @@ class Settings:
     logging = None
     yandex = None
     vosk = None
+    tinkoff = None
 
     def configure(self):
         self.work_dir = work_dir = abspath(self.work_dir or DEFAULT_WORK_DIR)
@@ -425,6 +492,7 @@ class Settings:
         self.logging = get_logging_config(work_dir)
         self.yandex = get_yandex_config(work_dir)
         self.vosk = get_vosk_config(work_dir)
+        self.tinkoff = get_tinkoff_config(work_dir)
 
         self.reconfigure_logging()
 
@@ -468,7 +536,11 @@ class Settings:
         return self._synthesizer
 
     def get_morphology_processor(self):
-        module = self.main['morphology_processor']
+        module = self.dialog_scheme.get('morphology_processor')
+        if not module:
+            module = self.main.get(
+                'morphology_processor',
+                'astersay.morphology.Pymorphy2Processor')
         try:
             Processor = import_string(module)
         except ImportError as e:
