@@ -615,12 +615,23 @@ class BaseDialog:
                 t.start()
             # Логгирование каких-либо строк из плагина.
             loggers = (
+                ('log_debug', log_debug),
+                ('log_info', log_info),
+                ('log_warning', log_warning),
+                ('log_error', log_error),
+                # TODO: удалить следующие параметры в версии 0.30:
                 ('debug', log_debug),
                 ('info', log_info),
                 ('warnings', log_warning),
                 ('errors', log_error),
             )
             for _name, _logger in loggers:
+                if _name in ("debug", "info", "warnings", "errors") and _name in plugin_data:
+                    # TODO: сменить на warning в версии 0.20:
+                    log_info(_(
+                        '< PLUGIN Параметр %r скоро устареет, используйте один из: '
+                        '"log_debug", "log_info", "log_warning" или "log_error"'
+                    ), _name)
                 strings = plugin_data.get(_name, [])
                 for string in strings:
                     _logger('< PLUGIN %s', string)
@@ -788,6 +799,8 @@ class BaseDialog:
         assert 'export_name' in script
         export_name = script['export_name']
         assert export_name and isinstance(export_name, str)
+        if 'initial_value' in script:
+            variables[export_name] = script['initial_value']
 
         pauses = script.get('pauses', {})
         make_pause(pauses, 'before')
@@ -903,6 +916,8 @@ class BaseDialog:
         assert 'export_name' in script
         export_name = script['export_name']
         assert export_name and isinstance(export_name, str)
+        if 'initial_value' in script:
+            variables[export_name] = script['initial_value']
 
         pauses = script.get('pauses', {})
         make_pause(pauses, 'before')
@@ -1016,6 +1031,8 @@ class BaseDialog:
         assert 'export_name' in script
         export_name = script['export_name']
         assert export_name and isinstance(export_name, str)
+        if 'initial_value' in script:
+            variables[export_name] = script['initial_value']
 
         assert 'regexp' in script
         regexp = script['regexp']
@@ -1141,6 +1158,8 @@ class BaseDialog:
         assert 'export_name' in script
         export_name = script['export_name']
         assert export_name and isinstance(export_name, str)
+        if 'initial_value' in script:
+            variables[export_name] = script['initial_value']
 
         assert 'file' in script
         filename = script['file']
@@ -1254,8 +1273,13 @@ class BaseDialog:
     def _script_simple_say(self, script, variables):
         assert script['type'] == 'simple_say'
 
-        if 'export_name' in script and 'export_value' in script:
-            variables[script['export_name']] = script['export_value']
+        if 'export_name' in script:
+            export_name = script['export_name']
+            assert export_name and isinstance(export_name, str)
+            if 'export_value' in script:
+                variables[export_name] = script['export_value']
+            elif 'initial_value' in script:
+                variables[export_name] = script['initial_value']
 
         pauses = script.get('pauses', {})
         make_pause(pauses, 'before')
@@ -1268,12 +1292,12 @@ class BaseDialog:
         if script.get('new_buffer', False):
             self.make_text_buffer()
 
+        result = True
         plugin_name = script.get('plugin_before')
         if plugin_name:
-            res, plugin_data = self.execute_plugin(plugin_name, '', '', variables)
+            res, plugin_data = self.execute_plugin(
+                plugin_name, result, '', variables)
             result = plugin_data.get('result')
-        else:
-            result = True
 
         saydata = script.get('say_start')
         if saydata:
@@ -1285,7 +1309,8 @@ class BaseDialog:
 
         plugin_name = script.get('plugin_after')
         if plugin_name:
-            res, plugin_data = self.execute_plugin(plugin_name, result, '', variables)
+            res, plugin_data = self.execute_plugin(
+                plugin_name, result, '', variables)
             result = plugin_data.get('result')
 
         if result:
